/**
 * gclc-socket:net.bigeon.gclc.socket.RemoteDisconnectCommand.java
 * Created on: Nov 18, 2017
 */
package net.bigeon.gclc.socket.cmd;

/*-
 * #%L
 * GCLC Socket
 * %%
 * Copyright (C) 2016 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */
import java.io.IOException;
import java.util.Collection;

import net.bigeon.gclc.command.Command;
import net.bigeon.gclc.exception.CommandRunException;
import net.bigeon.gclc.exception.CommandRunExceptionType;
import net.bigeon.gclc.manager.ConsoleInput;
import net.bigeon.gclc.manager.ConsoleOutput;
import net.bigeon.gclc.socket.ConnexionManager;

/** A {@link Command} to disconnect elements from a {@link ConnexionManager}.
 *
 * @author Emmanuel Bigeon
 * @param <T> the type of connected object */
public final class ConnexionListCommand<T> extends Command {

    /** The connexion manager. */
    private final ConnexionManager<T> manager;

    /** Create the connexion listing command.
     *
     * @param name the command name
     * @param manager the manager */
    public ConnexionListCommand(final String name, final ConnexionManager<T> manager) {
        super(name);
        this.manager = manager;
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.command.ICommand#execute(fr.bigeon.gclc.manager.
     * ConsoleOutput, fr.bigeon.gclc.manager.ConsoleInput, java.lang.String[]) */
    @Override
    public void execute(final ConsoleOutput out, final ConsoleInput in,
            final String... args) throws CommandRunException {
        final Collection<String> coll = manager.getConnected();
        try {
            for (final String string : coll) {
                out.println(string);
            }
        } catch (final IOException e) {
            throw new CommandRunException(CommandRunExceptionType.INTERACTION,
                    "User cannot be notified", e);
        }
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.command.ICommand#tip() */
    @Override
    public String tip() {
        return "List current connexions."; //$NON-NLS-1$
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.command.Command#usageDetail() */
    @Override
    protected String usageDetail() {
        return "";
    }
}
