/**
 * 
 */
package net.bigeon.gclc.swt;

/*-
 * #%L
 * GCLC swt
 * %%
 * Copyright (C) 2015 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;
import static org.mockito.Mockito.*;

import java.io.IOException;

import org.eclipse.swt.widgets.Text;
import org.junit.Test;

import net.bigeon.gclc.manager.PipedConsoleInput;
import net.bigeon.gclc.swt.io.ConsoleInputManager;

/** @author Emmanuel Bigeon */
public class ConsoleInputManagerTest {

    private final Text                text = mock(Text.class);
    private final ConsoleInputManager cim  = new ConsoleInputManager(text);

    /** Test method for
     * {@link net.bigeon.gclc.swt.io.ConsoleInputManager#setInput(java.lang.String)}. */
    @Test
    public void testSetText() {
        cim.setInput("Text");
        verify(text).setText("Text");
    }

    /** Test method for
     * {@link net.bigeon.gclc.swt.io.ConsoleInputManager#validateInput()}.
     * 
     * @throws IOException if an error occurred */
    @Test
    public void testValidateInput() throws IOException {
        // Expected calls
        when(text.getText()).thenReturn("abc");

        try {
            cim.validateInput();
            fail("No input should cause exception for input validation");
        } catch (final Exception e) {
            // ok
        }
        final PipedConsoleInput input = mock(PipedConsoleInput.class);
        cim.setManager(input);

        cim.validateInput();
        verify(input).type("abc");
    }

    @Test
    public void testValidateInputWithError() throws IOException {
        final PipedConsoleInput input = mock(PipedConsoleInput.class);
        cim.setManager(input);
        // Expected calls
        when(text.getText()).thenReturn("abc");
        doThrow(new IOException()).when(input).type("abc");

        try {
            cim.validateInput();
            fail("IO exception should be forwarded");
        } catch (final IOException e) {
            // ok
        }
    }

    /** Test method for
     * {@link net.bigeon.gclc.swt.io.ConsoleInputManager#getText()}. */
    @Test
    public void testGetText() {
        assertEquals("Text component should be preserved", text, cim.getText());
    }

    @Test
    public void testGetInput() {
        when(text.getText()).thenReturn("abc");
        assertEquals("Text component should be preserved", "abc", cim.getInput());
    }

}
